@@ -2,7 +2,7 @@ package Nephia;
 use strict;
 use warnings;
 use File::Spec;
-our $VERSION = '0.25';
+our $VERSION = '0.26';
 
 sub import {
     my ($class, %opts) = @_;
@@ -76,7 +76,7 @@ Look this examples.
 
       return {
           name => 'MyApp',
-          query => $req->param('q'),
+          query => param('q'),
       };
   };
 
@@ -127,8 +127,8 @@ You may specify code-reference that's passed to res() returns some value. These
 And, you can write like following.
 
   path '/cond/sample' => sub {
-      return res { 404 } unless req->param('q');
-      return res { ( 200, [], ['you say '. req->param('q')] ) };
+      return res { 404 } unless param('q');
+      return res { ( 200, [], ['you say '. param('q')] ) };
   };
 
 Commands supported in "res" function are following.
@@ -169,7 +169,7 @@ Please see Plack::Response's documentation for more detail.
   put '/baz' => sub { ... };
   del '/hoge' => sub { ... };
 
-=head2 How to use routing with Router::Simple style matching-pattern and capture it - Using param function
+=head2 How to use routing with Router::Simple style matching-pattern and capture it - Using param function WITHOUT args
 
   post '/item/{id:[0-9]+}' => sub {
       my $item_id = param->{id}; # get param named "id" from path
@@ -326,6 +326,10 @@ Return Plack::Response object with some DSL.
 
 Return parameters that contains in path as hashref.
 
+=head2 param $param_name
+
+Return specified query-parameter. (As like as "req->param($param_name)")
+
 =head2 config
 
 Return config as hashref.
